@@ -25,11 +25,26 @@
 #define HAVE_DIALOG_EDITOR_H
 
 
+typedef enum {
+    ED_TWEAK_NONE     = 1 << 1,
+    ED_TWEAK_TITLE    = 1 << 2, /* Window title */
+    ED_TWEAK_UI       = 1 << 3, /* Menu and button sensitivity */
+    ED_TWEAK_TAG_BAR  = 1 << 4,
+    ED_TWEAK_TEXTVIEW = 1 << 5, /* Card front and back textviews */
+    ED_TWEAK_INFO     = 1 << 6  /* Info textview and status bar */
+} EdTweak;
+
+#define ED_TWEAK_ALL \
+    ED_TWEAK_TITLE | ED_TWEAK_UI | ED_TWEAK_TAG_BAR | ED_TWEAK_TEXTVIEW | \
+    ED_TWEAK_INFO
+
+
 void   dialog_editor (Ignuit *ig);
 void   dialog_editor_check_changed (void);
 void   dialog_editor_kill (void);
-void   dialog_editor_tweak (void);
+void   dialog_editor_tweak (EdTweak tweak);
 void   dialog_editor_preferences_changed (void);
+void   dialog_editor_card_style_changed (void);
 
 
 #endif /* HAVE_DIALOG_EDITOR_H */
