@@ -1,7 +1,7 @@
 /* ignuit - Educational software for the GNOME, following the Leitner
  * flash-card system.
  *
- * Copyright (C) 2008, 2009, 2015 Timothy Richard Musson
+ * Copyright (C) 2008, 2009, 2015, 2016 Timothy Richard Musson
  *
  * Email: <trmusson@gmail.com>
  * WWW:   http://homepages.ihug.co.nz/~trmusson/programs.html#ignuit
@@ -185,6 +185,7 @@ start_element_handler (GMarkupParseContext *context,
             Category *cat;
 
             parser->state = STATE_IN_CATEGORY;
+
             s = attr_value ("title", attribute_names, attribute_values);
             cat = category_new (s);
             file_add_category (parser->file, cat);
@@ -195,6 +196,11 @@ start_element_handler (GMarkupParseContext *context,
                 category_set_fixed_order (cat, strcmp (s, "fixed") == 0);
             }
 
+            s = attr_value ("comment", attribute_names, attribute_values);
+            if (s != NULL) {
+                category_set_comment (cat, s);
+            }
+
         }
         else {
 
@@ -512,12 +518,17 @@ write_category_xml (FILE *fp, Category *cat)
     gchar *s;
 
 
-    s = g_markup_printf_escaped ("%s", category_get_title (cat));
+    s = g_markup_escape_text (category_get_title (cat), -1);
     fprintf (fp, "<category title='%s'", s);
     g_free (s);
 
     if (category_is_fixed_order (cat))
         fprintf (fp, " order='fixed'");
+
+    s = g_markup_escape_text (category_get_comment (cat), -1);
+    fprintf (fp, " comment='%s'", s);
+    g_free (s);
+
     fprintf (fp, ">\n");
 
     for (cur = category_get_cards (cat); cur != NULL; cur = cur->next)
